@@ -3,8 +3,8 @@ from nose.loader import TestLoader
 
 class BetterLoader(TestLoader):
 
-    def __init__(self, test_suite_func):
-        super(BetterLoader, self).__init__()
+    def __init__(self, test_suite_func, config):
+        super(BetterLoader, self).__init__(config)
         self.test_suite_func = test_suite_func
         
     def loadTestsFromModule(self, module, path=None, discovered=False):
@@ -27,9 +27,17 @@ class Plugin(NosePlugin):
                           default='test_suite',
                           help="A function in modules that will return a TestSuite. "
                                "Defaults to 'test_suite'.")
+        parser.add_option('--show-docstrings', dest='show_docstrings',
+                          action='store_true', default=False,
+                          help='Allow docstrings to be displayed as test '
+                          'descriptions.')
     
     def configure(self, options, config):
         self.test_suite_func = options.test_suite_func
+        self.show_docstrings = options.show_docstrings
         
     def prepareTestLoader(self, loader):
-        return BetterLoader(self.test_suite_func)
+        return BetterLoader(self.test_suite_func, loader.config)
+
+    def prepareTestResult(self, result):
+        result.descriptions = self.show_docstrings
